<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, shrink-to-fit=no">
    <title>{{ content[0]["title"]}}</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="css/single-blog.css">
    <!-- Mermaid-->
    <script defer src="https://cdn.jsdelivr.net/gh/highlightjs/cdn-release@11.5.1/build/highlight.min.js"></script>
    <script src="https://unpkg.com/mermaid@8.1.0/dist/mermaid.js"></script>
    <script>mermaid.initialize({startOnLoad:true});</script>
    <!-- Highlight JS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/highlightjs-themes@1.0.0/monokai_sublime.css">
    <link rel="stylesheet" href="https://cdn.rawgit.com/knsv/mermaid/0.5.6/dist/mermaid.css">
    <!--MathJax-->
    <script type="text/javascript" async src="https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.7/MathJax.js?config=TeX-MML-AM_CHTML"></script>

</head>

<body style="background: radial-gradient(circle, rgba(107,92,99,1) 0%, rgba(163,159,176,1) 49%, rgba(153,167,196,1) 100%);">
    <article style="margin-top: 25px;width: 98%;">
        <div class="card" style="background-color: rgba(27, 31, 34, 0.85);color: #f0f0f0 !important;">
            <div class="card-body">
            <button onclick="window.location.href='/blog'" class="btn btn-primary" type="button" style="background-color: rgba(248,248,248,0.46);box-shadow: 0 0 0 .25rem rgba(0,0,0,0);border-color: rgba(0,0,0,0);font-weight: 700;">&lt;-- Click to go back</button>
                <h4 style="margin-top:15px;" class="card-title">{{ content[0]["title"]}}</h4>
                <h6>Created: {{ content[0]["created"] }} <br>Updated: {{ content[0]["updated"] }}</h6>
                <p class="card-text">{{ content[1] | safe }}</p>
            </div>
        </div>
    </article>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>




