.card {
  background: #fff;
  transition: .5s;
  border: 0;
  margin-bottom: 30px;
  border-radius: .55rem;
  position: relative;
  width: 100%;
  box-shadow: 0 1px 2px 0 rgb(0 0 0 / 10%);
}

.card .body {
  color: #444;
  padding: 20px;
  font-weight: 400;
}

.card .header {
  color: #444;
  padding: 20px;
  position: relative;
  box-shadow: none;
}

.single_post {
  -webkit-transition: all .4s ease;
  transition: all .4s ease;
}

.single_post .body {
  padding: 30px;
}

.single_post .img-post {
  position: relative;
  overflow: hidden;
  max-height: 500px;
  margin-bottom: 30px;
}

.single_post .img-post > img {
  -webkit-transform: scale(1);
  -ms-transform: scale(1);
  transform: scale(1);
  opacity: 1;
  -webkit-transition: -webkit-transform .4s ease, opacity .4s ease;
  transition: transform .4s ease, opacity .4s ease;
  max-width: 100%;
  filter: none;
  -webkit-filter: grayscale(0);
  -webkit-transform: scale(1.01);
}

.single_post .img-post:hover img {
  -webkit-transform: scale(1.02);
  -ms-transform: scale(1.02);
  transform: scale(1.02);
  opacity: .7;
  filter: gray;
  -webkit-filter: grayscale(1);
  -webkit-transition: all .8s ease-in-out;
}

.single_post h3 {
  font-size: 20px;
  text-transform: uppercase;
}

.single_post h3 a {
  color: #242424;
  text-decoration: none;
}

.single_post p {
  font-size: 16px;
  line-height: 26px;
  font-weight: 300;
  margin: 0;
}

.right-box .categories-clouds li {
  display: inline-block;
  margin-bottom: 5px;
}

.right-box .categories-clouds li a {
  display: block;
  border: 1px solid;
  padding: 6px 10px;
  border-radius: 3px;
}

.right-box .instagram-plugin {
  overflow: hidden;
}

.right-box .instagram-plugin li {
  float: left;
  overflow: hidden;
  border: 1px solid #fff;
}

.comment-reply li {
  margin-bottom: 15px;
}

.comment-reply li:last-child {
  margin-bottom: none;
}

.comment-reply li h5 {
  font-size: 18px;
}

.comment-reply li p {
  margin-bottom: 0px;
  font-size: 15px;
  color: #777;
}

.comment-reply .list-inline li {
  display: inline-block;
  margin: 0;
  padding-right: 20px;
}

.comment-reply .list-inline li a {
  font-size: 13px;
}

@media (max-width: 640px) {
  .blog-page .single_post .body, .blog-page .single_post .footer {
    padding: 30px;
  }
}

.card {
  position: relative;
  display: flex;
  flex-direction: column;
  min-width: 0;
  word-wrap: break-word;
  background-color: #fff;
  background-clip: border-box;
  border: 0px solid rgba(0, 0, 0, 0);
  border-radius: .25rem;
  margin-bottom: 1.5rem;
  box-shadow: 0 2px 6px 0 rgb(218 218 253 / 65%), 0 2px 6px 0 rgb(206 206 238 / 54%);
}

div {
  margin: 1%;
}

.card-subtitle {
  color: #b5b5b5 !important;
}

